#include <Arduino.h>
#include <LiquidCrystal.h>
#include <Wire.h>
#include <RTClib.h>
#include <SPI.h>
#include <Ethernet.h>

//pins controle moteur
#define pinEnable 13 // Activation du driver/pilote
#define pinStep    9 // Signal de PAS (avancement)
#define pinDir     8 // Direction 
#define  pinms1     24 //MS1
#define  pinms2     25 //MS2
#define  pinms3     26 //MS3


EthernetClient client;
 
 
RTC_DS1307 RTC;
LiquidCrystal lcd(35, 36, 37, 38, 39, 34);

//shield ethernet
byte mac[] = { 0x90, 0xA2, 0xDA, 0x0F, 0x70, 0x39 };
byte ip[] = { 192, 168, 1, 69 };


//variable globale
int heure; //heure actuelle rtc
char recup[8]; // récupération tableau d'heure
int recup_matin=8 , recup_midi=12 , recup_goute=16 , recup_soir=21; // valeur par défaut
int OK=0; // si le patient a pris son médoc
int avance=0; //pour faire tourner d'une case le moteur

//capteur de lumière pour détection passage main
int photocellPin = 0; // the cell and 10K pulldown are connected to a0
int photocellReading; // the analog reading from the analog resistor divider


 
void setup() {
  Serial.begin(9600);
  
  //lcd + module rtc
  Wire.begin();
  RTC.begin();
  lcd.begin(16, 2);
  
  //haut parleur
  pinMode(33,OUTPUT);
  
  //Led alarme
  pinMode(32,OUTPUT);
  
  //Carte controle moteur
  pinMode( pinEnable, OUTPUT );
  pinMode( pinDir   , OUTPUT );
  pinMode( pinStep  , OUTPUT );
  pinMode( pinms1   , OUTPUT );
  pinMode( pinms2   , OUTPUT );
  pinMode( pinms3   , OUTPUT );
  
}




 
void loop() {
  
  affiche_heure();
  //Serial.print(heure);
  
  //recupération des variables dans le fichier horaires.txt sur wampserver
  recup_heure();  
  
  if ( (heure == recup_matin || heure == recup_midi || heure == recup_goute || heure == recup_soir) && OK==0  ){
   
   if (avance == 0){
     avance_moteur();
     avance = 1;
   }
   
   alarme();// on déclenche les voyants sonores et lumineux
    photocellReading = analogRead(photocellPin);
    if(photocellReading < 200){
      OK=1;
      avance=0;
      alarme(2);
    }
    
  }
    
  if (  (heure != recup_matin && heure != recup_midi && heure != recup_goute && heure != recup_soir) && OK ==0){
    OK = 1;
    avance =0;
    mail();
    alarme(1); 
   
  }
  
  
}

// CETTE FONCTION DECLENCHE LES ALARMES
void alarme(){
  
  digitalWrite(33,HIGH);
  digitalWrite(32,HIGH);
  delayMicroseconds(2000);
  digitalWrite(33,LOW);
  delayMicroseconds(2000);
  digitalWrite(32,LOW);
  delayMicroseconds(2000);
  
}


// CETTE FONTION DONNE LA VRAIE HEURE ET L4AFFICHE SUR UN LCD
void affiche_heure(){
  
 DateTime now = RTC.now();
  
 lcd.setCursor(5, 0);
  lcd.print(now.hour());
  lcd.print(":");
  if (now.minute() < 10) {
    lcd.print("0");
  }
  lcd.print(now.minute());
  
  // la date sur la deuxième ligne du LCD
  lcd.setCursor(0, 1); 
  lcd.print(now.day()); 
  lcd.print(" "); 
 
  switch (now.month()) {
  case 1:
    lcd.print("janvier");
    break;
  case 2:
    lcd.print("fevrier");
    break;
  case 3:
    lcd.print("mars");
    break;
  case 4:
    lcd.print("avril");
    break;
  case 5:
    lcd.print("mai");
    break;
  case 6:
    lcd.print("juin");
    break;
  case 7:
    lcd.print("juillet");
    break;
  case 8:
    lcd.print("aout");
    break;
  case 9:
    lcd.print("septembre");
    break;
  case 10:
    lcd.print("octobre");
    break;
  case 11:
    lcd.print("novembre");
    break;
  case 12:
    lcd.print("decembre");
    break;
  }
  lcd.print(" "); 
  lcd.print(now.year()); 
  delay(500);
  //lcd.clear();
  heure=now.hour();
  
}

// CETTE FONCTION PERMET DE RECUPERER LES VALEURS DE PRISE DE MEDOC QUI SONT ENREGISTRER DANS UN FICHIER TEXTE SUR LE SERVEUR. FONCTIONNE AVEC RECUP.PHP
void recup_heure(){
  
   Ethernet.begin(mac, ip);   
   delay(1000);   
   char server [] = "192.168.1.43"; // adresse du localhost 
   if (client.connect(server, 80)) 
   {
     client.println("GET /recup.php?recup=1 HTTP/1.1");
     client.println("Host: 192.168.1.43");
     client.println();
   } 
   else 
   {
     return;
   }
  // si on est connecté :
  if (client.available()) {    
    char c = client.read();// on lit la page    
    if(c=='#'){      // repére dans code php pour détection de l'heure
      int i = 0;
       while(client.available()){
           char c = client.read();           
           if (isdigit(c)){  //si c'est un chiffre alors on enregistre               
               recup[i]=c;
                i++;
           }           
       }         
    }   
    
   }
 recup_matin = (recup[0] - '0')*10 + recup[1] - '0';
 recup_midi = (recup[2] - '0')*10 + recup[3] - '0';
 recup_goute = (recup[4] - '0')*10 + recup[5] - '0';
 recup_soir = (recup[6] - '0')*10 + recup[7] - '0'; 
}
    
 // if the server's disconnected, stop the client:
 if (!client.connected()) 
 {
   client.stop();
 }
  
}

//CETTE FONCTION PERMET D4ENVOYER UN MAIL AU TUTEUR SI LE PATIENT NA PAS PRIS SON MEDICAMENT. FONCTIONNE AVEC MAIL.PHP
void mail(){
  
  Ethernet.begin(mac, ip);
 delay(1000);
  Serial.println("connecting...");
  char server [] = "192.168.1.43";
 // si la connection est éffectué au localhost
 if (client.connect(server, 80)) 
 {
   Serial.println("connected");
   // on accede au script php
   client.println("GET /mail.php?alerte=1 HTTP/1.1");
   client.println("Host: 192.168.1.43");
   client.println();
 } 
 else 
 {
   
   return;
 }
    
}


//CETTE FONCTION PERMET DE GERER LES ALARMES ET CREER UN HISTORIQUE DES ALARMES ACCESSIBLE SUR LE SITE. CETTE FONCTION FONCTIONNE AVEC LE SCRIPT PHP ALARME.PHP
void alarme (int choix){
  
   Ethernet.begin(mac, ip);
 delay(1000);
  Serial.println("connecting...");
  char server [] = "192.168.1.43";
 // si la connection est éffectué au localhost
 if (client.connect(server, 80)) 
 {
   Serial.println("connected");
   // on accede au script php
   
   
   if(choix==1){
   client.println("GET /alarme.php?alarme=1 HTTP/1.1");
   }else{
   client.println("GET /alarme.php?alarme=2 HTTP/1.1");
   }
   client.println("Host: 192.168.1.43");
   client.println();
 } 
 else 
 {
   
   return;
 }
  
  
  
}


//FONCTION PERMETTANT DE FAIRE AVANCER LE MOTEUR D UNE CASE EN EFFECTUANT DES 1/8 PAS
void avance_moteur(){
  
   int i = 0;
   digitalWrite (pinms1,HIGH);
   digitalWrite (pinms2,HIGH);
   digitalWrite (pinms3,LOW);
   digitalWrite( pinDir   , HIGH); // Direction avant
   digitalWrite( pinStep  , LOW);  // Initialisation de la broche step
    // déblocage de l'axe moteur
   Serial.println("Deblocage axe");
   digitalWrite( pinEnable, HIGH ); // logique inversée
 
 
  for (i=0; i<55;i++)
   {
     Serial.println(i);
     digitalWrite( pinStep,HIGH);
     delay(10);
     digitalWrite(pinStep,LOW);
     delay(10);
   }

  // blocage de l'axe moteur
   Serial.println("Blocage axe");
   digitalWrite( pinEnable, LOW ); // logique inversée
 
}
